import { ElementType, useCallback } from "react";
import { useAppDispatch } from "../../hooks";

export type FormDataChangeHandler = (e: any, setFormData: any) => void;

export const WithForm = (Component: ElementType) => {
  return function WithFormComponent({ ...props }: {
    [key: string]: any;
  }) {
    const dispatch = useAppDispatch();

    const dispatchFormData: FormDataChangeHandler = useCallback((
      { currentTarget }: any,
      setFormData: any
    ) => {
      const data: any = {};

      for (const input of currentTarget.elements) {
        if (input.name !== null && input.name !== '') {
          data[input.name] = input.value;
        }
      };

      dispatch(setFormData({
        data: {
          attributes: data,
        },
      }));
    }, [dispatch]);

    props = {
      handleFormDataChange: (e: any, setFormData: any) => {
        e.preventDefault();
        dispatchFormData(e, setFormData);
      },
      ...props,
    };

    return <Component {...props} />;
  };
};
